about summary refs log tree commit diff
path: root/library/std/src/error.rs
diff options
context:
space:
mode:
Diffstat (limited to 'library/std/src/error.rs')
-rw-r--r--library/std/src/error.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/library/std/src/error.rs b/library/std/src/error.rs
index fdeb280d240..361163d1970 100644
--- a/library/std/src/error.rs
+++ b/library/std/src/error.rs
@@ -145,15 +145,15 @@ pub trait Error: Debug + Display {
     /// }
     /// ```
     #[stable(feature = "rust1", since = "1.0.0")]
     #[rustc_deprecated(since = "1.42.0", reason = "use the Display impl or to_string()")]
     fn description(&self) -> &str {
         "description() is deprecated; use Display"
     }
 
     #[stable(feature = "rust1", since = "1.0.0")]
-    #[rustc_deprecated(
+    #[deprecated(
         since = "1.33.0",
-        reason = "replaced by Error::source, which can support downcasting"
+        note = "replaced by Error::source, which can support downcasting"
     )]
     #[allow(missing_docs)]
     fn cause(&self) -> Option<&dyn Error> {
@@ -145,15 +145,15 @@ pub trait Error: Debug + Display {
     /// ```
     #[stable(feature = "rust1", since = "1.0.0")]
-    #[rustc_deprecated(since = "1.42.0", reason = "use the Display impl or to_string()")]
+    #[deprecated(since = "1.42.0", note = "use the Display impl or to_string()")]
     fn description(&self) -> &str {
         "description() is deprecated; use Display"